/* Copyright (C) 2006 P.L. Lucas
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, 
 * Boston, MA 02111-1307, USA. 
 */

#ifndef __OPERATIONS_H__
#define __OPERATIONS_H__
#include "mainwindow.h"
#include "octave_connection.h"
#include "basewidget.h"
#include "table.h"
#include <QDialog>
#include <QLineEdit>
#include <QTreeWidget>
#include <QComboBox>
#include <QCheckBox>


//Esta clase sirve para presentar el men de los dibujos
class Plot:public QDialog
{
	Q_OBJECT
	public:
	enum Type {PLOT,SEMILOGY, SEMILOGX, LOGLOG, POLAR};
	Plot(QWidget *parent=0, Plot::Type type=PLOT);
	QString command();
	
	private:
	QLineEdit *x_lineedit, *y_lineedit, *title_lineedit;
	QVBoxLayout *vlayout;
	QComboBox *style_combo, *color_combo, *pointStyle_combo;
	QTreeWidget *plots_tree;
	QCheckBox *no_title;
	Plot::Type type;
	
	public slots:
	void add_callback();
	void remove_callback();
	void copy_clipboard_callback();
};


/*
Muestra asistentes para realizar operaciones bsicas con octave. 
*/

class Operations:public QObject
{
	Q_OBJECT
	public:
	Operations( QObject * parent = 0, BaseWidget **active_widget=0, MainWindow *main_window=0 );
	void setOctaveConnection(OctaveConnection *octave_connection);
	void setMatrix(QString matrix);
	private:
	OctaveConnection *octave_connection;
	QString matrix;
	BaseWidget **active_widget;
	MainWindow *main_window;
	enum MenuResult {ACCEPTED, COPY_CLIPBOARD, CANCEL}; //Se usa para saber el tipo de salida de un men
	bool copy_clipboard_ok;
	bool input_dialog(QString title, QString label, QString &input);
	void simple_comand(QString title, QString label, QString _command);
	MenuResult menu_window(QString title, QStringList parameters_labels, QStringList &parameters, QStringList output_labels, QStringList &output, QString help=QString());
	void compex_comand(QString title, QString _command, QStringList parameters_labels, QStringList &parameters, QStringList output_labels, QStringList &output, QString help=QString(), bool is_table=false);
	
	public slots:
	void copy_clipboard_callback();
	
	//Operaciones con matrices
	void inverse_callback();
	void determinant_callback();
	void eigenvalues_callback();
	void transpose_callback();
	void submatrix_callback();
	
	//Operaciones estadsticas
	void mean_callback();
	void median_callback();
	void std_callback();
	void cov_callback();
	void corrcoef_callback();
	
	//Plot menu
	void plot_callback();
	void axis_callback();
	void title_label_callback();
	void to_eps_callback();
	void to_pdf_callback();
	void to_png_callback();
	void semilogy_callback();
	void semilogx_callback();
	void log_log_callback();
	void polar_callback();
	void error_bars_callback();
	
	//General actions
	void editor_callback();
	
	//Config actions
	void general_config_callback();
};





#endif
